@@ -4,7 +4,7 @@ use warnings;
 
 package Crypt::Diceware;
 # ABSTRACT: Random passphrase generator loosely based on the Diceware algorithm
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Class::Load qw/load_class/;
 use Data::Entropy::Algorithms qw/pick_r/;
@@ -29,7 +29,8 @@ sub _build_words {
   return sub {
     my ($n) = @_;
     return unless $n && $n > 0;
-    return map { pick_r($list) } 1 .. int($n);
+    my @w = map { pick_r($list) } 1 .. int($n);
+    return wantarray ? @w : join(' ', @w);
   };
 }
 
@@ -42,13 +43,15 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Crypt::Diceware - Random passphrase generator loosely based on the Diceware algorithm
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -93,9 +96,13 @@ Exporting is done via L<Sub::Exporter> so any of its features may be used:
 
   my @phrase = words(4);
 
-Takes a positive numeric argument and returns a list of that many
-randomly-selected words.  Returns the empty list if the argument is missing or
-not a positive number.
+Takes a positive numeric argument and returns a passphrase of that many
+randomly-selected words. In a list context it will return a list of words, as above.
+In a scalar context it will return a string with the words separated with a single space character:
+
+  my $phrase = words(4);
+
+Returns the empty list / string if the argument is missing or not a positive number.
 
 =head1 SEE ALSO
 
@@ -176,6 +183,10 @@ L<https://github.com/dagolden/crypt-diceware>
 
 David Golden <dagolden@cpan.org>
 
+=head1 CONTRIBUTOR
+
+Neil Bowers <neil@bowers.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by David Golden.
