@@ -4,7 +4,7 @@ use warnings;
 
 package Crypt::Diceware::Wordlist::Original;
 # ABSTRACT: Crypt::Diceware wordlist from the original Diceware list
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our @Words = qw{
   a a&p a's aa aaa aaaa aaron ab aba ababa aback abase abash abate abbas abbe
@@ -584,13 +584,15 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Crypt::Diceware::Wordlist::Original - Crypt::Diceware wordlist from the original Diceware list
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -620,6 +622,10 @@ L<Crypt::Diceware>
 
 David Golden <dagolden@cpan.org>
 
+=head1 CONTRIBUTOR
+
+Neil Bowers <neil@bowers.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by David Golden.
